@@ -130,6 +130,10 @@ AWAKENING_ID_TO_EMOJI_NAME_MAP = {
     124: 'lcombo_super',
     125: 'dcombo_super',
     126: 'misc_TA',
+    127: 'allstatboost',
+    128: 'blessing_yang',
+    129: 'blessing_yin',
+    130: 'misc_aging',
 }
 
 AWAKENING_RESTRICTED_LATENT_VALUE_TO_EMOJI_NAME_MAP = {
