@@ -23,7 +23,7 @@ class MonsterHeader:
     def box_with_emoji(cls, m, *, link=True, prefix=None,
                        qs: Optional[QuerySettings] = None):
         msg = f"{m.monster_no} - {m.name_en}"
-        suffix = cls._jp_suffix(m, False, False)
+        suffix = cls._server_suffix(m, False, False)
         return Box(
             prefix,
             Text(get_attribute_emoji_by_monster(m)),
@@ -39,12 +39,20 @@ class MonsterHeader:
                                   qs=qs).to_markdown()
 
     @classmethod
-    def _jp_suffix(cls, m, is_jp_buffed=False, subname_on_override=True):
+    def _server_suffix(cls, m, is_jp_buffed=False, subname_on_override=True):
         suffix = ""
         if m.roma_subname and (subname_on_override or m.name_en_override is None):
             suffix += ' [{}]'.format(m.roma_subname)
         if not m.on_na:
-            suffix += ' (JP only)'
+            if m.reskin_id is not None:
+                suffix += ' (Has reskin)'
+            else:
+                suffix += ' (JP only)'
+        elif not m.on_jp:
+            if m.reskin_id is not None:
+                suffix += ' (Is reskin)'
+            else:
+                suffix += ' (NA only)'
         if is_jp_buffed:
             suffix += ' (JP buffed)'
         return suffix
@@ -56,5 +64,5 @@ class MonsterHeader:
         To celebrate 1000 issues/PRs in our main Tsubaki repo, we added this easter egg! Yay!
         """
         tsubaki_punctuation = '!' if is_tsubaki else ''
-        suffix = cls._jp_suffix(m, is_jp_buffed)
+        suffix = cls._server_suffix(m, is_jp_buffed)
         return f'[{m.monster_no}] {m.name_en}{tsubaki_punctuation}{suffix}'
